darkhistory.physics.coll_exc_xsec — DarkHistory documentation

# darkhistory.physics.coll_exc_xsec

`darkhistory.physics.` `coll_exc_xsec`(eng, species=None)

  e-e collisional excitation cross section in cm2.

  See 0906.1197.

  Parameters: | eng : float or ndarray Abscissa of kinetic energies. species : {‘HI’, ‘HeI’, ‘HeII’} Species of interest.
  Returns: | float or ndarray e-e collisional excitation cross section.

#### Previous topic

darkhistory.physics.photo_ion_xsec

#### Next topic

darkhistory.physics.coll_ion_sec_elec_spec

### This Page

Show Source